@@ -9,6 +9,9 @@ from os import path
 import Options
 from mingus.core import diatonic
 
+APP_NAME = "pyImproviser"
+APP_VERSION = "0.7.1.3"
+
 class OptionClass:
 	movement = "Movement"
 	width=400
@@ -34,6 +37,14 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.fill_combos()
 		self.connect_widgets()
 		self.set_defaults()
+		self.set_title()
+
+	def set_title(self):
+		p = "Untitled.imp"
+		if self.lastfile != "":
+			p = self.lastfile
+		self.setWindowTitle("%s - %s" % (APP_NAME, p))
+
 
 	def fill_combos(self):
 		for x in Options.get_available_instruments():
@@ -163,10 +174,9 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 				o = Options.load_options_from_file(s, OptionClass())
 				self.set_options(o)
 				self.lastfile = s
+				self.set_title()
 			except Options.OptionError, err:
-				print err
-
-			
+				self.set_status(err)
 
 
 	def save_file(self):
@@ -177,7 +187,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 				Options.save_options(self.lastfile, 
 					self.get_options())
 			except IOError:
-				print "Couldn't open file for writing"
+				self.set_status("Error: Couldn't open file for writing")
 
 	def save_dialog(self):
 		f = QtGui.QFileDialog()
@@ -192,8 +202,9 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 				Options.save_options(filename, 
 					self.get_options())
 				self.lastfile = filename
+				self.set_title()
 			except IOError:
-				print "Couldn't open file for writing"
+				self.set_status("Error: Couldn't open file for writing")
 
 	def set_options(self, options):
 		o = options
@@ -278,6 +289,10 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 				return x
 		return -1
 	
+	def set_status(self, msg):
+		s = self.statusBar()
+		s.showMessage(str(msg))
+
 	def start_simulation(self):
 		o = self.get_options()
 
@@ -288,7 +303,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			seq.play()
 			self.lastmidi = o.midifile
 		except Options.OptionError, err:
-			print err
+			self.set_status(err)
 
 		self.ui.startbutton.setEnabled(True)
 		self.ui.stopbutton.setEnabled(False)
